@@ -10,7 +10,7 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::Config;
-$App::SpreadRevolutionaryDate::Config::VERSION = '0.46';
+$App::SpreadRevolutionaryDate::Config::VERSION = '0.47';
 # ABSTRACT: Companion class of L<App::SpreadRevolutionaryDate>, to handle configuration file and command line arguments, subclass of L<AppConfig>.
 
 use Moose;
@@ -274,7 +274,13 @@ sub parse_file {
                 File::HomeDir->my_home . '/.spread-revolutionary-date.conf') {
     $filename = $default_path if (!$filename && -f $default_path)
   }
-  $self->file($filename);
+  if ($filename && !ref($filename)) {
+      my $fh;
+      open($fh, '<:encoding(UTF-8)', $filename);
+      $self->file($fh);
+  } else {
+      $self->file($filename);
+  }
 }
 
 
@@ -416,7 +422,7 @@ App::SpreadRevolutionaryDate::Config - Companion class of L<App::SpreadRevolutio
 
 =head1 VERSION
 
-version 0.46
+version 0.47
 
 =head1 METHODS
 
